import sys
import os
import re
import math

#usage:
#python c:\showVersions.py M:\PROJECT render 2 5.5GB
#"M:\PROJECT" - the root directory to start the search from
#"render" - optional keyword
#2 - minimum number of versions allowed
#5.5GB - minimum size of found versions

if len(sys.argv) > 1:
    rootSearch = sys.argv[1]
    verPattern = re.compile('(.*)(v\d+)(.*)')
    sizePattern = re.compile('^(\d+\.?\d*)|(\d*\.?\d+)GB$')
    keyword = ''
    minVersionDirs = 1
    minSize = 0.0
    
    for i in range(2, len(sys.argv)):
        arg = sys.argv[i];
        if arg.isdigit():
            minVersionDirs = int(arg)
        elif sizePattern.search(arg):
            search = sizePattern.search(arg)
            if search.groups()[0]:
                minSize = float(search.groups()[0])
            else:
                minSize = float(search.groups()[1])
        else:
            keyword = arg

    print('')
    
    for root, dirs, files in os.walk(rootSearch):
        if keyword in root or not keyword:
            versions = []
            size = 0.0

            for dir in dirs:
                search = verPattern.search(dir)
                if search:
                    pattern = '^{}v\d+{}$'.format(\
                    search.groups()[0], search.groups()[2])
                    compPattern = re.compile(pattern)
                    versionDirs = []

                    for dir in dirs:
                        if compPattern.match(dir):
                            versionDirs.append(dir)

                    if len(versionDirs) > minVersionDirs:
                        for version in versionDirs:
                            if version not in versions:
                                versions.append(version)

            if minSize and versions:
                for version in versions:
                    versionPath = os.path.join(root, version)
                    for verRoot, verDirs, verFiles in os.walk(versionPath):
                        for file in verFiles:
                            path = os.path.join(verRoot, file)
                            size += os.path.getsize(path)

                size /= pow(1024, 3);

                if size < minSize:
                    del versions[:]

            if versions:
                print(root.replace('/', os.sep))
                if minSize:
                    print('Versions size: {:.2f} GB'.format(size))
                for version in versions:
                    print(version)
                    
                print('')

input("Press Enter to continue...")